Crate whiskers_derive

Crate whiskers_derive 

Attribute Macros

sketch_app
Attribute macro to automatically derive some of the required traits for a sketch app.
sketch_widget
Attribute macro to automatically derive some of the required traits for a sketch widget.

Derive Macros

Sketch
Widget