Crate whiskers_derive
whiskers_
derive
0.5.0
All Items
Crate Items
Attribute Macros
Derive Macros
Crate
whiskers_
derive
Attribute Macros

sketch_
app
Attribute macro to automatically derive some of the required traits for a sketch app.
sketch_
widget
Attribute macro to automatically derive some of the required traits for a sketch widget.
Derive Macros

Sketch
Widget